@@ -21,7 +21,7 @@
     51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include <config.h>
+#include "config.h"
 
 #include <ctype.h>
 #include <fcntl.h>
@@ -191,8 +191,36 @@ static unsigned kmluks_get_properties(const bound_tgtdefn_t *boundtgt)
 }
 
 
-/*!
- *  Change the password associated with a given LUKS key-slot.
+/*! @brief Change UID to match EUID when mounting via loopback device
+ *
+ *  This is a workaround for recent versions of libcryptsetup
+ *  (since January 2017), which check that both uid==0 and euid==0
+ *  before attempting to create a loopback device
+ *  for a filesystem in an ordinary file. Setting up the loopback
+ *  device usually only requires euid==0.
+ *
+ *  For filesystems in ordinary block devices, this function has no effect.
+ *  Otherwise, this will call setuid() to attempt to make uid==euid==0,
+ *  which appears to be an irreversible change, so will persist
+ *  across any other actions taken by cryptmount within the same process.
+ *
+ *  @returns The previous value of UID.
+ */
+static uid_t luks_patch_uid(const bound_tgtdefn_t* boundtgt)
+{   const uid_t olduid = getuid();
+    const char* filename = boundtgt->tgt->key.filename;
+    struct stat sbuff;
+
+    if (stat(filename, &sbuff) == 0
+        && S_ISREG(sbuff.st_mode)) {
+        (void)setuid(geteuid());
+    }
+
+    return olduid;
+}
+
+
+/*! @brief Change the password associated with a given LUKS key-slot.
  *
  *  This will either create an entirely new keyslot with the given password,
  *  or attempt to change the password associated with a particular keyslot
@@ -267,6 +295,8 @@ static int kmluks_get_key(bound_tgtdefn_t *boundtgt,
      *  -- see http://code.google.com/p/cryptsetup/issues/detail?id=47,
      * which are mitigated by kmluks_init_algs(). */
 
+    luks_patch_uid(boundtgt);
+
     snprintf(label, sizeof(label), "cm-luks-tmp-%d-%x",
              getpid(), (unsigned)(size_t)tgt);
 
