@@ -21,7 +21,7 @@
     51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include <config.h>
+#include "config.h"
 
 #include <ctype.h>
 #include <errno.h>
@@ -800,7 +800,7 @@ int cm_mutex_lock(void)
 
     (void)cm_path(&fname, CM_SYSRUN_PFX, cm_lock_filename);
     snprintf(ident, sizeof(ident), "%u-%u",
-                (unsigned)getpid(), (unsigned)getuid());
+             (unsigned)getpid(), (unsigned)getuid());
 
     while (tries-->0) {
         errno = 0;
