@@ -23,7 +23,7 @@
 
 #ifdef TESTING
 
-#include <config.h>
+#include "config.h"
 
 #include <stdio.h>
 
