@@ -21,7 +21,7 @@
     51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include <config.h>
+#include "config.h"
 
 #include <ctype.h>
 #include <fcntl.h>
@@ -59,6 +59,11 @@
 #  include "cmtesting.h"
 #endif
 
+
+/** Record of getuid() output at start of process */
+uid_t cm_initial_uid = ~0u;
+
+
 /**
  *  An element within a linked-list of filesystem-targets,
  *  typically supplied from command-line.
@@ -393,7 +398,7 @@ static int do_devsetup(const km_pw_context_t *pw_ctxt,
 
     readonly = is_readonlyfs(tgt->dev);
     eflag = blockify_file(tgt->dev, (readonly ? O_RDONLY : O_RDWR),
-                        tgt->loopdev, &tgtdev, &isloop);
+                          tgt->loopdev, &tgtdev, &isloop);
     if (eflag != ERR_NOERROR) {
         fprintf(stderr, _("Cannot open device \"%s\" for target \"%s\"\n"),
                 (tgt->dev != NULL ? tgt->dev : "(NULL)"), tgt->ident);
@@ -560,7 +565,7 @@ static int do_mount(const km_pw_context_t *pw_ctxt, bound_tgtdefn_t *boundtgt)
     }
 
     tstat = alloc_tgtstatus(tgt);
-    tstat->uid = (unsigned long)getuid();
+    tstat->uid = (unsigned long)cm_initial_uid;
     put_tgtstatus(tgt, tstat);
     free_tgtstatus(tstat);
 
@@ -600,7 +605,7 @@ static int do_unmount(const bound_tgtdefn_t *boundtgt)
     }
 
     /* Check if filing system has been mounted & locked by another user: */
-    if (getuid() != 0 && (uid_t)tstat->uid != getuid()) {
+    if (getuid() != 0 && (uid_t)tstat->uid != cm_initial_uid) {
         pwent = getpwuid((uid_t)tstat->uid);
         if (pwent != NULL) {
             fprintf(stderr, _("Only \"%s\" can unmount \"%s\"\n"),
@@ -670,7 +675,7 @@ static int do_swapon(const km_pw_context_t *pw_ctxt, bound_tgtdefn_t *boundtgt)
     }
 
     tstat = alloc_tgtstatus(tgt);
-    tstat->uid = (unsigned long)getuid();
+    tstat->uid = (unsigned long)cm_initial_uid;
     put_tgtstatus(tgt, tstat);
     free_tgtstatus(tstat);
 
@@ -1073,7 +1078,7 @@ static void check_priv_opt(const char *opt)
 static int check_priv_tgt(const tgtdefn_t *tgt)
     /** Check if ordinary user is allowed to perform privileged actions */
 {
-    if ((tgt->flags & FLG_USER) == 0 && getuid() != 0) {
+    if ((tgt->flags & FLG_USER) == 0 && cm_initial_uid != 0) {
         fprintf(stderr, _("Only root can configure \"%s\"\n"), tgt->ident);
         return ERR_BADPRIV;
     }
@@ -1098,7 +1103,7 @@ static int execute_list(cmmode_t mode, const tgtdefn_t *tgttable,
     struct passwd *pwent = NULL;
     const char *username = NULL, *syslogmsg = NULL;
 
-    pwent = getpwuid(getuid());
+    pwent = getpwuid(cm_initial_uid);
     username = (pwent != NULL ? pwent->pw_name : "UNKNOWN");
 
 #if defined(HAVE_SYSLOG) && !defined(TESTING)
@@ -1450,6 +1455,7 @@ int main(int argc, char *argv[])
     textdomain(PACKAGE);
 #endif
 
+    cm_initial_uid = getuid();
     init_env_dictionary();
 
 #ifdef TESTING
