@@ -25,7 +25,9 @@
 #ifndef _CRYPTMOUNT_H
 #define _CRYPTMOUNT_H
 
-#include <config.h>
+#include "config.h"
+
+#include <sys/types.h>
 
 #if HAVE_INTTYPES_H
 #  include <inttypes.h>
@@ -56,6 +58,7 @@
 #  define bindtextdomain(Package, Directory) /* empty */
 #endif
 
+extern uid_t cm_initial_uid;
 
 enum    /*! Exit-codes */
 {
