@@ -24,7 +24,7 @@
 #ifndef _DMUTILS_H
 #define _DMUTILS_H
 
-#include <config.h>
+#include "config.h"
 
 #include <libdevmapper.h>
 
